Colour Volume
=============

Optimal Colour Stimuli - MacAdam Limits
---------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    is_within_macadam_limits
    OPTIMAL_COLOUR_STIMULI_ILLUMINANTS

Mesh Volume
-----------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    is_within_mesh_volume

Pointer's Gamut
---------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    is_within_pointer_gamut

RGB Volume
----------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    RGB_colourspace_limits
    RGB_colourspace_pointer_gamut_coverage_MonteCarlo
    RGB_colourspace_visible_spectrum_coverage_MonteCarlo
    RGB_colourspace_volume_MonteCarlo
    RGB_colourspace_volume_coverage_MonteCarlo

Rösch-MacAdam Colour solid - Visible Spectrum
---------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    is_within_visible_spectrum

**Ancillary Objects**

``colour.volume``

.. currentmodule:: colour.volume

.. autosummary::
    :toctree: generated/

    generate_pulse_waves
    XYZ_outer_surface
    solid_RoschMacAdam
